@@ -208,10 +208,10 @@ class Configuration extends \Doctrine\DBAL\Configuration
     }
 
     /**
-     * @deprecated No replacement planned.
-     *
      * Adds a namespace under a certain alias.
      *
+     * @deprecated No replacement planned.
+     *
      * @param string $alias
      * @param string $namespace
      *
@@ -227,7 +227,7 @@ class Configuration extends \Doctrine\DBAL\Configuration
                 $alias
             );
         } else {
-            NotSupported::createForPersistence3(sprintf(
+            throw NotSupported::createForPersistence3(sprintf(
                 'Using short namespace alias "%s" by calling %s',
                 $alias,
                 __METHOD__
