@@ -77,8 +77,8 @@ class OneToOneBidirectionalAssociationTest extends OrmFunctionalTestCase
     public function testLazyLoadsObjectsOnTheOwningSide(): void
     {
         $this->createFixture();
-        $metadata                                               = $this->_em->getClassMetadata(ECommerceCart::class);
-        $metadata->associationMappings['customer']['fetchMode'] = ClassMetadata::FETCH_LAZY;
+        $metadata                                           = $this->_em->getClassMetadata(ECommerceCart::class);
+        $metadata->associationMappings['customer']['fetch'] = ClassMetadata::FETCH_LAZY;
 
         $query  = $this->_em->createQuery('select c from Doctrine\Tests\Models\ECommerce\ECommerceCart c');
         $result = $query->getResult();
