@@ -5,6 +5,7 @@ declare(strict_types=1);
 namespace Doctrine\Tests\ORM\Functional;
 
 use Doctrine\Common\Collections\ArrayCollection;
+use Doctrine\Common\Persistence\PersistentObject;
 use Doctrine\DBAL\Logging\Middleware as LoggingMiddleware;
 use Doctrine\ORM\Mapping\ClassMetadata;
 use Doctrine\ORM\NonUniqueResultException;
@@ -485,13 +486,35 @@ class QueryTest extends OrmFunctionalTestCase
     public function testGetSingleScalarResultThrowsExceptionOnNoResult(): void
     {
         $this->expectException('Doctrine\ORM\NoResultException');
-        $this->_em->createQuery('select a from Doctrine\Tests\Models\CMS\CmsArticle a')
+        $this->_em->createQuery('select a.id from Doctrine\Tests\Models\CMS\CmsArticle a')
              ->getSingleScalarResult();
     }
 
+    public function testGetSingleScalarResultThrowsExceptionOnSingleRowWithMultipleColumns(): void
+    {
+        $user           = new CmsUser();
+        $user->name     = 'Javier';
+        $user->username = 'phansys';
+        $user->status   = 'developer';
+
+        $this->_em->persist($user);
+
+        $this->_em->flush();
+        $this->_em->clear();
+
+        $this->expectException(NonUniqueResultException::class);
+        $this->expectExceptionMessage(
+            'The query returned a row containing multiple columns. Change the query or use a different result function'
+            . ' like getScalarResult().'
+        );
+
+        $this->_em->createQuery('select u from Doctrine\Tests\Models\CMS\CmsUser u')
+            ->setMaxResults(1)
+            ->getSingleScalarResult();
+    }
+
     public function testGetSingleScalarResultThrowsExceptionOnNonUniqueResult(): void
     {
-        $this->expectException('Doctrine\ORM\NonUniqueResultException');
         $user           = new CmsUser();
         $user->name     = 'Guilherme';
         $user->username = 'gblanco';
@@ -514,7 +537,12 @@ class QueryTest extends OrmFunctionalTestCase
         $this->_em->flush();
         $this->_em->clear();
 
-        $this->_em->createQuery('select a from Doctrine\Tests\Models\CMS\CmsArticle a')
+        $this->expectException(NonUniqueResultException::class);
+        $this->expectExceptionMessage(
+            'The query returned multiple rows. Change the query or use a different result function like getScalarResult().'
+        );
+
+        $this->_em->createQuery('select a.id from Doctrine\Tests\Models\CMS\CmsArticle a')
              ->getSingleScalarResult();
     }
 
@@ -557,6 +585,10 @@ class QueryTest extends OrmFunctionalTestCase
 
     public function testSupportsQueriesWithEntityNamespaces(): void
     {
+        if (! class_exists(PersistentObject::class)) {
+            self::markTestSkipped('This test requires doctrine/persistence 2');
+        }
+
         $this->_em->getConfiguration()->addEntityNamespace('CMS', 'Doctrine\Tests\Models\CMS');
 
         try {
